arXivDaily arXiv每日学术速递 周一至周五更新
arXiv 2007.06932cs.CV
收藏

REPrune:通过代表选举进行过滤器修剪

REPrune: Filter Pruning via Representative Election

Korea Institute of Science and Technology(韩国科学技术研究院)

Mincheol Park, Woojeong Kim, Suhyun Kim

摘要:

尽管基于范数的过滤器修剪方法被广泛接受,但在确定要修剪的过滤器时,“较小范数不太重要”的标准是否是最优的仍值得怀疑。特别是当我们只能保留原始滤波器的一小部分时,更重要的是选择能够最好地代表整个滤波器的滤波器,而不管范数值如何。我们的新的修剪方法,题为“REPrune”解决这个问题,通过聚类选择有代表性的过滤器。通过从一组相似的过滤器中选择一个过滤器,避免选择相邻的大过滤器,REPrune可以在相似的精度下实现更好的压缩率。我们的方法还可以更快地恢复精度,并且在微调过程中需要较小的滤波器偏移。从经验上讲,REPrune减少了超过49%的FLOP,在ResNet-110上为CIFAR-10提供了0.53%的准确性增益。此外,REPrune在ResNet-18上减少了超过41.8%的FLOPs,其中ImageNet的Top-1验证损失为1.67%。

英文摘要:

Even though norm-based filter pruning methods are widely accepted, it is questionable whether the "smaller-norm-less-important" criterion is optimal in determining filters to prune. Especially when we can keep only a small fraction of the original filters, it is more crucial to choose the filters that can best represent the whole filters regardless of norm values. Our novel pruning method entitled "REPrune" addresses this problem by selecting representative filters via clustering. By selecting one filter from a cluster of similar filters and avoiding selecting adjacent large filters, REPrune can achieve a better compression rate with similar accuracy. Our method also recovers the accuracy more rapidly and requires a smaller shift of filters during fine-tuning. Empirically, REPrune reduces more than 49% FLOPs, with 0.53% accuracy gain on ResNet-110 for CIFAR-10. Also, REPrune reduces more than 41.8% FLOPs with 1.67% Top-1 validation loss on ResNet-18 for ImageNet.

机构、总结、中文摘要均由AI分析而来,可能存在错误,请以论文正文为准。

↑